@@ -31,7 +31,7 @@
 static int ipkg_conf_parse_file(ipkg_conf_t *conf, const char *filename,
 				pkg_src_list_t *pkg_src_list,
 				nv_pair_list_t *tmp_dest_nv_pair_list,
-				char *tmp_lists_dir);
+				char **tmp_lists_dir);
 static int ipkg_init_options_array(const ipkg_conf_t *conf, ipkg_option_t **options);
 static int ipkg_conf_set_option(const ipkg_option_t *options,
 				const char *name, const char *value);
@@ -164,7 +164,7 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
 	  err = stat(args->conf_file, &stat_buf);
 	  if (err == 0)
 	       if (ipkg_conf_parse_file(conf, args->conf_file,
-				    &conf->pkg_src_list, &tmp_dest_nv_pair_list,lists_dir)<0) {
+				    &conf->pkg_src_list, &tmp_dest_nv_pair_list,&lists_dir)<0) {
                    /* Memory leakage from ipkg_conf_parse-file */
                    return -1;
                }
@@ -192,7 +192,7 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
 	  for (i = 0; i < globbuf.gl_pathc; i++) {
 	       if (globbuf.gl_pathv[i]) 
 		    if ( ipkg_conf_parse_file(conf, globbuf.gl_pathv[i], 
-				         &conf->pkg_src_list, &tmp_dest_nv_pair_list,lists_dir)<0) {
+				         &conf->pkg_src_list, &tmp_dest_nv_pair_list,&lists_dir)<0) {
                         /* Memory leakage from ipkg_conf_parse-file */
                         return -1;
 	            }
@@ -446,7 +446,7 @@ static int set_and_load_pkg_dest_list(ipkg_conf_t *conf, nv_pair_list_t *nv_pair
 static int ipkg_conf_parse_file(ipkg_conf_t *conf, const char *filename,
 				pkg_src_list_t *pkg_src_list,
 				nv_pair_list_t *tmp_dest_nv_pair_list,
-				char *lists_dir)
+				char **lists_dir)
 {
      int err;
      ipkg_option_t * options;
@@ -556,9 +556,9 @@ static int ipkg_conf_parse_file(ipkg_conf_t *conf, const char *filename,
 	  } else if (strcmp(type, "dest") == 0) {
 	       nv_pair_list_append(tmp_dest_nv_pair_list, name, value);
 	  } else if (strcmp(type, "lists_dir") == 0) {
-	       lists_dir = realloc(lists_dir,strlen(value)+1);
-               sprintf (lists_dir,"%s",value);
-               if (lists_dir == NULL) {
+	       *lists_dir = realloc(*lists_dir,strlen(value)+1);
+               sprintf (*lists_dir,"%s",value);
+               if (*lists_dir == NULL) {
 		    ipkg_message(conf, IPKG_ERROR, "ERROR: Not enough memory\n");
 	            free(options);
 	            return EINVAL;
