@@ -246,6 +246,30 @@ int pkg_hash_fetch_unsatisfied_dependencies(ipkg_conf_t *conf, pkg_t * pkg,
      return unsatisfied->len;
 }
 
+/*checking for conflicts !in replaces 
+  If a packages conflicts with another but is also replacing it, I should not consider it a 
+  really conflicts 
+  returns 0 if conflicts <> replaces or 1 if conflicts == replaces 
+*/
+int is_pkg_a_replaces(pkg_t *pkg_scout,pkg_t *pkg){
+
+int i ;
+int replaces_count = pkg->replaces_count;
+
+ if (pkg->replaces_count==0)    // No replaces, it's surely a conflict
+    return 0;
+
+    abstract_pkg_t **replaces = pkg->replaces;
+
+    for (i = 0; i < replaces_count; i++) {
+        if (strcmp(pkg_scout->name,pkg->replaces[i]->name)==0)       // Found
+            return 1;
+    }
+    return 0;
+
+}
+
+
 /* Abhaya: added support for conflicts */
 pkg_vec_t * pkg_hash_fetch_conflicts(hash_table_t * hash, pkg_t * pkg)
 {
@@ -274,6 +298,8 @@ pkg_vec_t * pkg_hash_fetch_conflicts(hash_table_t * hash, pkg_t * pkg)
 
     count = pkg->conflicts_count;
 
+
+
     /* foreach conflict */
     for(i = 0; i < pkg->conflicts_count; i++){
 
@@ -298,7 +324,7 @@ pkg_vec_t * pkg_hash_fetch_conflicts(hash_table_t * hash, pkg_t * pkg)
                         continue; 
                     }
 		    if ((pkg_scout->state_status == SS_INSTALLED || pkg_scout->state_want == SW_INSTALL) &&
-		       version_constraints_satisfied(possible_satisfier, pkg_scout)){
+		       version_constraints_satisfied(possible_satisfier, pkg_scout) && !is_pkg_a_replaces(pkg_scout,pkg)){
  	 	        if (!is_pkg_in_pkg_vec(installed_conflicts, pkg_scout)){
 			    pkg_vec_insert(installed_conflicts, pkg_scout);
 			}
